@@ -30,6 +30,7 @@ use temp_cfg_reg_value::TempCfgRegValue;
 
 pub const SPI_READ_BIT: u8 = 0x80;
 
+#[derive(Copy, Clone)]
 pub struct AngleAnd1GOffset {
     angle: u16,
     offset: u16,
@@ -116,7 +117,7 @@ fn check_if_bit_is_set(value: u8, bit_position: u8) -> bool {
     ((value >> bit_position) & 0b1).eq(&0b1)
 }
 
-#[derive(Default)]
+#[derive(Clone, Copy, Default)]
 pub struct Lis3dh {
     ctrl_reg0: CtrlReg0Value,
     temp_cfg_reg: TempCfgRegValue,
@@ -127,6 +128,25 @@ pub struct Lis3dh {
 }
 
 impl Lis3dh {
+    fn ctrl_reg0_setting(&self) -> CtrlReg0Value {
+        self.ctrl_reg0
+    }
+    fn temp_cfg_reg_setting(&self) -> TempCfgRegValue {
+        self.temp_cfg_reg
+    }
+    fn ctrl_reg1_setting(&self) -> CtrlReg1Value {
+        self.ctrl_reg1
+    }
+    fn ctrl_reg2_setting(&self) -> CtrlReg2Value {
+        self.ctrl_reg2
+    }
+    fn ctrl_reg3_setting(&self) -> CtrlReg3Value {
+        self.ctrl_reg3
+    }
+    fn ctrl_reg4_setting(&self) -> CtrlReg4Value {
+        self.ctrl_reg4
+    }
+
     pub fn set_output_data_rate(
         &mut self,
         output_data_rate: ctrl_reg_1_value::ODR,
@@ -152,14 +172,6 @@ impl Lis3dh {
             spi,
             [RegisterAddresses::CtrlReg0 as u8, self.ctrl_reg0 as u8],
         )?;
-        self.write_to_spi(
-            cs,
-            spi,
-            [
-                RegisterAddresses::TempCfgReg as u8,
-                self.temp_cfg_reg.get_raw_value(),
-            ],
-        )?;
         self.write_to_spi(
             cs,
             spi,
@@ -202,6 +214,35 @@ impl Lis3dh {
         )
     }
 
+    pub fn check_if_settings_are_written_correctly<CS, SPI, CsE, SpiE>(
+        &mut self,
+        cs: &mut CS,
+        spi: &mut SPI,
+    ) -> Result<bool, Error<CsE, SpiE>>
+    where
+        CS: OutputPin<Error = CsE>,
+        SPI: Transfer<u8, Error = SpiE> + Write<u8, Error = SpiE>,
+    {
+        Ok(self
+            .ctrl_reg0_setting()
+            .eq(&self.get_ctrl_reg_0_value(cs, spi)?)
+            && self
+                .ctrl_reg1_setting()
+                .eq(&self.get_ctrl_reg_1_value(cs, spi)?)
+            && self
+                .ctrl_reg2_setting()
+                .eq(&self.get_ctrl_reg_2_value(cs, spi)?)
+            && self
+                .ctrl_reg3_setting()
+                .eq(&self.get_ctrl_reg_3_value(cs, spi)?)
+            && self
+                .ctrl_reg4_setting()
+                .eq(&self.get_ctrl_reg_4_value(cs, spi)?)
+            && self
+                .temp_cfg_reg_setting()
+                .eq(&self.get_temp_cfg_reg(cs, spi)?))
+    }
+
     pub fn get_ctrl_reg_4_value<CS, SPI, CsE, SpiE>(
         &mut self,
         cs: &mut CS,
